title: Hello World
slug: hello-world
date: 2015-04-13 18:00:00
tags: opensource, python
files: tor-people.jpg, gnulaptop.png
---

_Welcome to monopati!_

This is a sample blog post, containing two pictures.

![Keep walking](tor-people.jpg)

![hack around](gnulaptop.png)
